const {
    app,
    BrowserWindow,
    WebContentsView,
    BaseWindow,
    session,
    ipcMain,
    dialog,
} = require("electron");
const WebApp = require("./src/utils/WebApp");
const {
    parse_arg,
    openUrlInBrowser,
    wildCardMatchList,
} = require("./src/utils/swai_utils");
const path = require("path");
const fs = require("fs");
const Ecosystem = require("./src/utils/Ecosystem");
const os = require("os");

// Import new manager classes
const LockFileManager = require("./src/managers/LockFileManager");
const WindowManager = require("./src/managers/WindowManager");

// Check for the debug mode argument
let debug_mode =
    parse_arg("--debug_mode") != null && parse_arg("--debug_mode") === "true";

let windowManager = null;

app.on("window-all-closed", () => {
    app.quit();
});

app.on("ready", async () => {
    try {
        const filePath = process.argv[2];
        if (!filePath) {
            console.error("No file path provided");
            app.quit();
            return;
        }
        if (!fs.existsSync(filePath)) {
            console.error(`File doesn't exist: ${filePath}`);
            app.quit();
            return;
        }
        const webapp = WebApp.from_yaml_file(filePath);

        if (!LockFileManager.handleLockFile(webapp.app_id)) {
            // If handleLockFile returns false, it means another instance is running
            // and app.quit() has already been called inside handleLockFile.
            return; // Stop execution here
        }

        app.commandLine.appendSwitch("ozone-platform-hint", "auto");
        app.setName(webapp.app_id);

        // Initialize components
        windowManager = new WindowManager(debug_mode);

        // Create the main window
        windowManager.createWindow(webapp);

        app.on('will-quit', () => {
            // Make sure webapp is defined before trying to access app_id
            if (webapp && webapp.app_id) {
                LockFileManager.removeLockFile(webapp.app_id);
            }
        });
    } catch (e) {
        console.error(e);
        app.quit();
    }
});